@@ -7,10 +7,9 @@
 import os
 
 from beets.plugins import BeetsPlugin
-
-from beets.util import bytestring_path
 from beets.util.confit import ConfigSource, load_yaml
 
+from beetsplug.goingrunning import common as GRC
 from beetsplug.goingrunning.command import GoingRunningCommand
 
 
